
#ifndef KDEGAMES_EXPORT_H
#define KDEGAMES_EXPORT_H

#ifdef LIBKDEGAMES_STATIC_DEFINE
#  define KDEGAMES_EXPORT
#  define LIBKDEGAMES_NO_EXPORT
#else
#  ifndef KDEGAMES_EXPORT
#    ifdef KF5KDEGames_EXPORTS
        /* We are building this library */
#      define KDEGAMES_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KDEGAMES_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef LIBKDEGAMES_NO_EXPORT
#    define LIBKDEGAMES_NO_EXPORT 
#  endif
#endif

#ifndef KDE_DEPRECATED
#  define KDE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDE_DEPRECATED_EXPORT
#  define KDE_DEPRECATED_EXPORT KDEGAMES_EXPORT KDE_DEPRECATED
#endif

#ifndef KDE_DEPRECATED_NO_EXPORT
#  define KDE_DEPRECATED_NO_EXPORT LIBKDEGAMES_NO_EXPORT KDE_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef LIBKDEGAMES_NO_DEPRECATED
#    define LIBKDEGAMES_NO_DEPRECATED
#  endif
#endif

#endif
